@@ -84,8 +84,10 @@ class SpikeSorterGUI(ttk.Frame):
                                command=self.umap_split_clusters)
         save = ttk.Button(buttons, text='Save Cells', command=self.save)
         viewWaves = ttk.Button(buttons, text='View Waves', command=self.view_waves)
-        viewRecWaves = ttk.Button(buttons, text='View Waves by Rec',
-                                  command=self.view_waves_by_rec)
+        # viewRecWaves = ttk.Button(buttons, text='View Waves by Rec',
+        #                           command=self.view_waves_by_rec)
+        viewTimeWaves = ttk.Button(buttons, text='View Waves over Time',
+                                  command=self.view_waves_over_time)
         viewPCA = ttk.Button(buttons, text='View PCA', command=self.view_pca)
         viewUMAP = ttk.Button(buttons, text='View UMAP', command=self.view_umap)
         viewWAVELET = ttk.Button(buttons, text='View Wavelets', command=self.view_wavelets)
@@ -100,7 +102,8 @@ class SpikeSorterGUI(ttk.Frame):
         splitUMAP.pack(side='top', fill='x', pady=5)
         save.pack(side='top', fill='x', pady=5)
         viewWaves.pack(side='top', fill='x', pady=5)
-        viewRecWaves.pack(side='top', fill='x', pady=5)
+        # viewRecWaves.pack(side='top', fill='x', pady=5)
+        viewTimeWaves.pack(side='top', fill='x', pady=5)
         viewPCA.pack(side='top', fill='x', pady=5)
         viewUMAP.pack(side='top', fill='x', pady=5)
         viewWAVELET.pack(side='top', fill='x', pady=5)
@@ -230,7 +233,7 @@ class SpikeSorterGUI(ttk.Frame):
         if len(chosen) == 0:
             return
 
-        self.sorter.plot_clusters_waveforms(chosen)
+        self.sorter.plot_clusters_waveforms(chosen, threshold=self.sorter._detection_thresholds[0])
 
     def view_waves_by_rec(self, *args):
         chosen = self._check_bar.get_selected()
@@ -242,6 +245,26 @@ class SpikeSorterGUI(ttk.Frame):
 
         self.sorter.plot_cluster_waveforms_by_rec(chosen)
 
+    def view_waves_over_time(self, *args):
+        chosen = self._check_bar.get_selected()
+        if len(chosen) != 1:
+            return
+
+        if isinstance(chosen, list):
+            chosen = chosen[0]
+
+        params = {'interval': int}
+        popup = userIO.fill_dict_popup(params, master=self.root,
+                                       prompt='Input time interval for segments (in seconds)')
+        self.disable_all()
+        self.root.wait_window(popup.root)
+        self.enable_all()
+        params = popup.output
+        if popup.cancelled or params['interval'] is None:
+            return
+
+        self.sorter.plot_cluster_waveforms_over_time(chosen, params['interval'])
+
     def view_pca(self, *args):
         chosen = self._check_bar.get_selected()
         if len(chosen) == 0:
